@@ -53,7 +53,7 @@ class Foreperson:
                                            'instrument': 'i07',
                                            'sample': None}}
         self.reduction = {'software': 'islatu', 'yaml': None}
-        if self.n_columns == 3
+        if self.n_columns == 3:
             self.data = {'column 1': 'Qz / Aa^-1', 'column 2': 'RQz', 'column 3': 'sigma RQz , standard deviation'}
         elif self.n_columns == 4:
             self.data = {'column 1': 'Qz / Aa^-1', 'column 2': 'RQz', 'column 3': 'sigma RQz , standard deviation', 'column 4': 'dQz-by-Qz , resolution'}
